import java.io.IOException;

import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.henshin.interpreter.EGraph;
import org.eclipse.emf.henshin.interpreter.Engine;
import org.eclipse.emf.henshin.interpreter.UnitApplication;
import org.eclipse.emf.henshin.interpreter.impl.EGraphImpl;
import org.eclipse.emf.henshin.interpreter.impl.EngineImpl;
import org.eclipse.emf.henshin.interpreter.impl.UnitApplicationImpl;
import org.eclipse.emf.henshin.model.Module;
import org.eclipse.emf.henshin.model.Unit;
import org.eclipse.emf.henshin.model.resource.HenshinResourceSet;

public class Main {
	public static void main(String[] args) throws IOException {
		String workingDir = "models";
		String input = "size10.xmi";
		String output = "size10-changed.xmi";
		String transformation = "cdrefinement.henshin";
		String unit = "AssociationClass2Class";

		HenshinResourceSet resourceSet = new HenshinResourceSet(workingDir);

		// Load the Henshin module:
		Module module = resourceSet.getModule(transformation);

		// Load a model:
		Resource model = resourceSet.getResource(input);

		// Apply the transformation (see below)...

		// Prepare the engine:
		Engine engine = new EngineImpl();

		// Initialize the graph:
		EGraph graph = new EGraphImpl(model);

		// Find the unit to be applied:
		Unit u = module.getUnit(unit);

		// Apply the unit:
		UnitApplication application = new UnitApplicationImpl(engine, graph, u, null);
		boolean success = application.execute(null);
		System.out.println("Finished successfully: " + success);

		// Save the model:
		Resource outputResource = resourceSet.createResource(output);
		outputResource.getContents().addAll(model.getContents());
		outputResource.save(null);

	}
}
